@@ -1,7 +1,7 @@
 from protmo.pm import *
 from protmo.ast import *
 from protmo.grpc_ast import AstToGrpcAst
-
+from protmo.settings_loader  import settings
 
 def create_proto_file(package: str) -> None:
 
@@ -17,9 +17,9 @@ def create_proto_file(package: str) -> None:
         if proto_messages.service:
             content += str(proto_messages.service) + '\n\n'
         for proto_msg in proto_messages.messages[1:]:
-            if not proto_msg.name in seen:
+            if proto_msg.name not in seen:
                 content += str(proto_msg) + '\n\n'
                 seen.add(proto_msg.name)
 
-    with open(f'{package}.proto', 'w') as f:
+    with open(f'{settings.proto_folder}/{package}.proto', 'w') as f:
         f.write(content)
