@@ -3,6 +3,7 @@ from protmo.ast import *
 from protmo.utils import *
 from protmo.settings_loader import settings
 
+
 class _PythonToDart:
 
     python_dt_to_dart = {
@@ -13,7 +14,9 @@ class _PythonToDart:
         bool: 'bool',
         str: 'String',
         'str': 'String',
-        'Void': 'void'
+        'Void': 'void',
+        'bytes': 'List<int>',
+        bytes: 'List<int>'
     }
 
     def __init__(self):
@@ -58,6 +61,7 @@ class AstToDartAst:
 
 def dart_type(python_type, repeated=False):
     res = _python_to_dart.python_datatype_to_dart(python_type)
+    res = res.split('.')[-1]
     if repeated:
         res = f'List<{res}>'
     return res
