@@ -1,14 +1,17 @@
+from __future__ import annotations
 from pymongo import MongoClient
 from google.protobuf.json_format import MessageToDict, ParseDict
 import uuid
 import time
 from typing import Dict
 from typing import List
-
+from protmo.provide import use_provided
 from protmo.pm import Message
 
 DB_KEY = 1
 
+def db() -> Db:
+    return use_provided(DB_KEY)
 
 class Db:
     '''
@@ -75,6 +78,15 @@ class Db:
         # loose this data)
         return ParseDict(doc, message, ignore_unknown_fields=True)
 
+    def get(self, messageClass: type, **kwargs):
+        res = self.query(messageClass, query=kwargs)
+        if not res:
+            return None
+        return res[0]
+
+    def all(self, messageClass: type, include_deleted=False):
+        return self.query(messageClass, query={}, include_deleted=include_deleted)
+
     def query(self, messageClass: type, query: Dict = {},
               include_deleted: bool = False) -> List[Message]:
         '''
