@@ -10,17 +10,11 @@ from typing import Any
 from protmo.name_to_protobuf import *
 from protmo.provide import use_provided
 
-
 def request_user():
     USER_KEY = 2
     return use_provided(USER_KEY)
 
 
-def db():
-    from protmo.db import DB_KEY
-    return use_provided(DB_KEY)
-
-
 class Message:
     '''
     To define your model, create classes which extend this class. Then
@@ -120,8 +114,9 @@ class Message:
         except Exception as e:
             # TODO: this is called in regen, but there is no proto-file as it is just generated
             # right now. Thus name_to_grpc_message_or_method(name) returns None, which causes an error
-            # but this should be the normal case at this state, thus there is an design error here 
-            proto = {}
+            # but this should be the normal case at this state, thus there is
+            # an design error here
+            proto = None
         # We use the Message class to wrap the proto-message-class which holds the actual data.
         # thus we set the data into the proto-attribute and whenever someone asks us for data
         # we take it from there
@@ -283,6 +278,7 @@ class Message:
 
         Also used for lazy-loading resolve in the __getattribute__ part.
         '''
+        from protmo.db import db
         return db()
 
     # @property
